@@ -57,6 +57,7 @@ struct DownloadConfig
     bool bDuplicateHandler;
     bool bGalaxyDependencies;
     bool bDeleteOrphans;
+    bool bGalaxyLowercasePath;
 };
 
 struct gameSpecificConfig
@@ -222,6 +223,7 @@ struct CurlConfig
     curl_off_t iDownloadRate;
     long int iLowSpeedTimeout;
     long int iLowSpeedTimeoutRate;
+    std::string sInterface;
 };
 
 class Config
@@ -241,7 +243,6 @@ class Config
         bool bUpdated;
         bool bNew;
         bool bCheckStatus;
-        bool bShowWishlist;
         bool bNotifications;
         bool bIncludeHiddenProducts;
         bool bSizeOnly;
