@@ -227,7 +227,6 @@ int main(int argc, char *argv[])
             ("no-platform-detection", bpo::value<bool>(&bNoPlatformDetection)->zero_tokens()->default_value(false), "Don't try to detect supported platforms from game shelf.\nSkips the initial fast platform detection and detects the supported platforms from game details which is slower but more accurate.\nUseful in case platform identifier is missing for some games in the game shelf.\nUsing --platform with --list doesn't work with this option.")
             ("download-file", bpo::value<std::string>(&Globals::globalConfig.sFileIdString)->default_value(""), "Download files using fileid\n\nFormat:\n\"gamename/fileid\"\n\"gamename/dlc_gamename/fileid\"\n\"gogdownloader://gamename/fileid\"\n\"gogdownloader://gamename/dlc_name/fileid\"\n\nMultiple files:\n\"gamename1/fileid1,gamename2/fileid2,gamename2/dlcname/fileid1\"\n\nThis option ignores all subdir options. The files are downloaded to directory specified with --directory option.")
             ("output-file,o", bpo::value<std::string>(&Globals::globalConfig.sOutputFilename)->default_value(""), "Set filename of file downloaded with --download-file.")
-            ("wishlist", bpo::value<bool>(&Globals::globalConfig.bShowWishlist)->zero_tokens()->default_value(false), "Show wishlist")
             ("cacert", bpo::value<std::string>(&Globals::globalConfig.curlConf.sCACertPath)->default_value(""), "Path to CA certificate bundle in PEM format")
             ("respect-umask", bpo::value<bool>(&Globals::globalConfig.bRespectUmask)->zero_tokens()->default_value(false), "Do not adjust permissions of sensitive files")
             ("user-agent", bpo::value<std::string>(&Globals::globalConfig.curlConf.sUserAgent)->default_value(DEFAULT_USER_AGENT), "Set user agent")
@@ -292,6 +291,7 @@ int main(int argc, char *argv[])
             ("check-free-space", bpo::value<bool>(&Globals::globalConfig.dlConf.bFreeSpaceCheck)->zero_tokens()->default_value(false), "Check for available free space before starting download")
             ("no-fast-status-check", bpo::value<bool>(&bNoFastStatusCheck)->zero_tokens()->default_value(false), "Don't use fast status check.\nMakes --status much slower but able to catch corrupted files by calculating local file hash for all files.")
             ("trust-api-for-extras", bpo::value<bool>(&Globals::globalConfig.bTrustAPIForExtras)->zero_tokens()->default_value(false), "Trust API responses for extras to be correct.")
+            ("interface", bpo::value<std::string>(&Globals::globalConfig.curlConf.sInterface)->default_value(""), "Perform operations using a specified network interface")
         ;
 
         options_cli_no_cfg_hidden.add_options()
@@ -314,6 +314,7 @@ int main(int argc, char *argv[])
             ("subdir-galaxy-install", bpo::value<std::string>(&Globals::globalConfig.dirConf.sGalaxyInstallSubdir)->default_value("%install_dir%"), galaxy_install_subdir_text.c_str())
             ("galaxy-cdn-priority", bpo::value<std::string>(&sGalaxyCDN)->default_value("edgecast,akamai_edgecast_proxy,fastly"), galaxy_cdn_priority_text.c_str())
             ("galaxy-list-cdns", bpo::value<std::string>(&galaxy_product_id_list_cdns)->default_value(""), "List available CDNs for game using product id [product_id/build_index] or gamename regex [gamename/build_id]\nBuild index is used to select a build and defaults to 0 if not specified.\n\nExample: 12345/2 selects build 2 for product 12345")
+            ("galaxy-lowercase-path", bpo::value<bool>(&Globals::globalConfig.dlConf.bGalaxyLowercasePath)->zero_tokens()->default_value(false), "Make filepath lowercase for Windows game files")
         ;
 
         options_cli_all.add(options_cli_no_cfg).add(options_cli_cfg).add(options_cli_experimental);
@@ -801,9 +802,7 @@ int main(int argc, char *argv[])
 
     int res = 0;
 
-    if (Globals::globalConfig.bShowWishlist)
-        downloader.showWishlist();
-    else if (Globals::globalConfig.bUpdateCache)
+    if (Globals::globalConfig.bUpdateCache)
         downloader.updateCache();
     else if (Globals::globalConfig.bNotifications)
         downloader.checkNotifications();
@@ -828,89 +827,89 @@ int main(int argc, char *argv[])
         downloader.checkStatus();
     else if (!galaxy_product_id_show_builds.empty())
     {
-        int build_index = -1;
+        std::string build_id;
         std::vector<std::string> tokens = Util::tokenize(galaxy_product_id_show_builds, "/");
         std::string product_id = tokens[0];
         if (tokens.size() == 2)
         {
-            build_index = std::stoi(tokens[1]);
+            build_id = tokens[1];
         }
-        downloader.galaxyShowBuilds(product_id, build_index);
+        downloader.galaxyShowBuilds(product_id, build_id);
     }
     else if (!galaxy_product_id_show_cloud_paths.empty())
     {
-        int build_index = -1;
+        std::string build_id;
         std::vector<std::string> tokens = Util::tokenize(galaxy_product_id_show_cloud_paths, "/");
         std::string product_id = tokens[0];
         if (tokens.size() == 2)
         {
-            build_index = std::stoi(tokens[1]);
+            build_id = tokens[1];
         }
-        downloader.galaxyShowCloudSaves(product_id, build_index);
+        downloader.galaxyShowCloudSaves(product_id, build_id);
     }
     else if (!galaxy_product_id_show_local_cloud_paths.empty())
     {
-        int build_index = -1;
+        std::string build_id;
         std::vector<std::string> tokens = Util::tokenize(galaxy_product_id_show_local_cloud_paths, "/");
         std::string product_id = tokens[0];
         if (tokens.size() == 2)
         {
-            build_index = std::stoi(tokens[1]);
+            build_id = tokens[1];
         }
-        downloader.galaxyShowLocalCloudSaves(product_id, build_index);
+        downloader.galaxyShowLocalCloudSaves(product_id, build_id);
     }
     else if (!galaxy_product_cloud_saves_delete.empty())
     {
-        int build_index = -1;
+        std::string build_id;
         std::vector<std::string> tokens = Util::tokenize(galaxy_product_cloud_saves_delete, "/");
         std::string product_id = tokens[0];
         if (tokens.size() == 2)
         {
-            build_index = std::stoi(tokens[1]);
+            build_id = tokens[1];
         }
-        downloader.deleteCloudSaves(product_id, build_index);
+        downloader.deleteCloudSaves(product_id, build_id);
     }
     else if (!galaxy_product_id_install.empty())
     {
-        int build_index = -1;
+        std::string build_id;
         std::vector<std::string> tokens = Util::tokenize(galaxy_product_id_install, "/");
         std::string product_id = tokens[0];
         if (tokens.size() == 2)
         {
-            build_index = std::stoi(tokens[1]);
+            build_id = tokens[1];
         }
-        downloader.galaxyInstallGame(product_id, build_index, Globals::globalConfig.dlConf.iGalaxyArch);
+        downloader.galaxyInstallGame(product_id, build_id, Globals::globalConfig.dlConf.iGalaxyArch);
     }
     else if (!galaxy_product_id_list_cdns.empty())
     {
-        int build_index = -1;
+        std::string build_id;
         std::vector<std::string> tokens = Util::tokenize(galaxy_product_id_list_cdns, "/");
         std::string product_id = tokens[0];
         if (tokens.size() == 2)
         {
-            build_index = std::stoi(tokens[1]);
+            build_id = tokens[1];
         }
-        downloader.galaxyListCDNs(product_id, build_index);
+        downloader.galaxyListCDNs(product_id, build_id);
     }
     else if (!galaxy_product_cloud_saves.empty()) {
-        int build_index = -1;
+        std::string build_id;
         std::vector<std::string> tokens = Util::tokenize(galaxy_product_cloud_saves, "/");
         std::string product_id = tokens[0];
         if (tokens.size() == 2)
         {
-            build_index = std::stoi(tokens[1]);
+            build_id = tokens[1];
         }
-        downloader.downloadCloudSaves(product_id, build_index);
+        downloader.downloadCloudSaves(product_id, build_id);
     }
     else if (!galaxy_upload_product_cloud_saves.empty()) {
-        int build_index = -1;
+        std::string build_id;
         std::vector<std::string> tokens = Util::tokenize(galaxy_upload_product_cloud_saves, "/");
         std::string product_id = tokens[0];
         if (tokens.size() == 2)
         {
-            build_index = std::stoi(tokens[1]);
+            build_id = tokens[1];
         }
-        downloader.uploadCloudSaves(product_id, build_index);
+        downloader.uploadCloudSaves(product_id, build_id);
     }
     else
     {
